# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]

## [2020.11.0]

### Changelog
- regenerated avpr based on recent traits update
- remove is-homeable trait

## [2020.10.0]

### Fixed
- Spelling of `reset_to_known_position`

## [2020.07.0]

### Changed
- Now uses Avro-RPC [YEP-107](https://yeps.yaq.fyi/107/)
- Uses Flit for distribution

## [2020.05.0]

### Added
- initial release

[Unreleased]: https://gitlab.com/yaq/yaqd-pmc/-/compare/v2020.11.0...master
[2020.11.0]: https://gitlab.com/yaq/yaqd-pmc/-/compare/v2020.10.0...v2020.11.0
[2020.10.0]: https://gitlab.com/yaq/yaqd-pmc/-/compare/v2020.07.0...v2020.10.0
[2020.07.0]: https://gitlab.com/yaq/yaqd-pmc/-/compare/v2020.05.0...v2020.07.0
[2020.05.0]: https://gitlab.com/yaq/yaqd-pmc/-/tags/v2020.05.0
